﻿using CaseAccountingContracts.BindingModels;
using CaseAccountingContracts.BusinessLogicContracts;
using CaseAccountingContracts.SearchModels;
using CaseAccountingContracts.ViewModels;
using Microsoft.AspNetCore.Mvc;

namespace CaseAccountingRestApi.Controllers
{
    [Route("api/[controller]/[action]")]
    [ApiController]
    public class LawyerController : Controller
    {
        private readonly ILawyerLogic lawyerLogic;

        private readonly ICaseLogic _caseLogic;

        public LawyerController(ILawyerLogic logic, ICaseLogic caseLogic)
        {
            lawyerLogic = logic;
            _caseLogic = caseLogic;
        }

        [HttpGet]
        public LawyerViewModel? Get(int id)
        {
            try
            {
                return lawyerLogic.ReadElement(new LawyerSearchModel { Id = id });
            }
            catch (Exception)
            {
                throw;
            }
        }

        [HttpGet]
        public List<LawyerViewModel>? GetAllByUser(int userId)
        {
            try
            {
                return lawyerLogic.ReadList(null);
            }
            catch (Exception)
            {
                throw;
            }
        }

        [HttpPost]
        public void Create(LawyerBindingModel model)
        {
            try
            {
                lawyerLogic.Create(model);
            }
            catch (Exception)
            {
                throw;
            }
        }

        [HttpPost]
        public void Update(LawyerBindingModel model)
        {
            try
            {
                lawyerLogic.Update(model);
            }
            catch (Exception)
            {
                throw;
            }
        }

        [HttpPost]
        public void Delete(LawyerBindingModel model)
        {
            try
            {
                lawyerLogic.Delete(new() { Id = model.Id });
            }
            catch (Exception)
            {
                throw;
            }
        }

        [HttpGet]
        public List<CaseViewModel>? GetAllCases()
        {
            try
            {
                return _caseLogic.ReadList(null);
            }
            catch (Exception ex)
            {
                throw;
            }
        }

        [HttpGet]
        public List<LawyerViewModel>? GetAllByUserAndSpecialization(int userId, int specialization)
        {
            try
            {
                return lawyerLogic.ReadList(new LawyerSearchModel { UserId = userId, SpecializationId = specialization });
            }
            catch (Exception ex)
            {
                throw;
            }
        }
    }
}
